@@ -61,8 +61,8 @@ class ClientImpl : public QObject
     Q_OBJECT
 
 public:
-    ClientImpl(Client *interface, QObject *parent = 0);
-    ~ClientImpl();
+    ClientImpl(Client *interface, QObject *parent = nullptr);
+    ~ClientImpl() override;
 
     Action *addClientAction(const QString &shortcut, const QString &path, const QString &description, QObject *parent);
 
