@@ -174,7 +174,7 @@
         <translation>Per defecte</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Tanca</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Vol continuar?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Plataforma no compatible</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>Les claus globals d&apos;LXQt actualment no són compatibles amb Wayland.
+
+Les dreceres globals es poden configurar a la configuració del compositor.</translation>
+    </message>
+</context>
 </TS>
