@@ -174,7 +174,7 @@
         <translation>Standard</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Luk</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Vil du fortsætte?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Platform ikke understøttet</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>LXQt globale genveje er i øjeblikket ikke understøttet under Wayland.
+
+Globale genveje skal i stedet defineres i indstillinger for kompositoren.</translation>
+    </message>
+</context>
 </TS>
