@@ -175,7 +175,7 @@
         <translation>Vorgabe</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Schließen</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
         <translation>Ihre definierten Tastaturbefehle werden entfernt. Möchten Sie fortfahren?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Plattform nicht unterstützt</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>LXQt globalkeys werden unter Wayland derzeit nicht unterstützt.
+
+Globale Tastenkombinationen können stattdessen in den Einstellungen des Kompositors konfiguriert werden.</translation>
+    </message>
+</context>
 </TS>
