@@ -174,7 +174,7 @@
         <translation>Εξ ορισμού</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Κλείσιμο</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Θέλετε να συνεχίσετε;</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Μη υποστηριζόμενο πλατύβαθρο</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>Οι καθολικές συντομεύσεις LXQt δεν υποστηρίζονται στο Wayland.
+
+Αντί αυτού, μπορούν να διαμορφωθούν από τις ρυθμίσεις του.</translation>
+    </message>
+</context>
 </TS>
