@@ -174,7 +174,7 @@
         <translation>Predeterminado</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Cerrar</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 ¿Quiere proseguir?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Plataforma No Soportada</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>Las teclas globales de LXQt actualmente no son soportadas bajo Wayland.
+
+En su lugar, los atajos globales se pueden configurar en los ajustes del compositor.</translation>
+    </message>
+</context>
 </TS>
