@@ -174,7 +174,7 @@
         <translation>Taasta vaikeseadistused</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Sulge</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Kas sa soovid jätkata?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>See platvorm pole toetatud</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>LXQt globalkeys ei ole hetkel Wayland&apos;i kasutamisel toetatud.
+
+Selle asemel saad üldisi kiirklahve seadistada komposiitori eelistustes.</translation>
+    </message>
+</context>
 </TS>
