@@ -174,7 +174,7 @@
         <translation>Oletusasetukset</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Sulje</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Haluatko jatkaa?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Alustaa ei tueta</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>LXQt:n työpöydänlaajuisia pikanäppäimiä ei vielä tueta Waylandiä käytettäessä.
+
+Työpöydänlaajuiset pikanäppäimet määritetään koostajan asetuksissa.</translation>
+    </message>
+</context>
 </TS>
