@@ -175,7 +175,7 @@
         <translation>Par défaut</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Fermer</translation>
     </message>
@@ -192,4 +192,21 @@ Do you want to proceed?</source>
 Voulez-vous procéder&#x202f;?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Plateforme non prise en charge</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>LXQT GlobalKeys n&apos;est actuellement pas pris en charge dans Wayland.
+
+Les raccourcis globaux peuvent être configurés dans les paramètres du compositeur.</translation>
+    </message>
+</context>
 </TS>
