@@ -174,7 +174,7 @@
         <translation>בררת מחדל</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>סגירה</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 להמשיך?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>הפלטפורמה לא נתמכת</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>אין עדיין תמיכה במקשי קיצור כלליים של LXQt תחת Wayland.
+
+את מקשי הקיצור הגלובליים אפשר להגדיר בהגדרות הניהול החלונאי במקום.</translation>
+    </message>
+</context>
 </TS>
