@@ -174,7 +174,7 @@
         <translation>既定値</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>閉じる</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 続けますか？</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>プラットフォームがサポートされていません</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>現在、Wayland では LXQt グローバルキーはサポートされていません。
+
+代わりに、コンポジターの設定でグローバルショートカットを設定できます。</translation>
+    </message>
+</context>
 </TS>
