@@ -174,7 +174,7 @@
         <translation>기본값</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>닫기</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 계속하시겠습니까?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>플랫폼 지원되지 않음</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>LXQt globalkeys는 현재 Wayland에서 지원되지 않습니다.
+
+전역 단축키는 대신 컴포지터 설정에서 구성할 수 있습니다.</translation>
+    </message>
+</context>
 </TS>
