@@ -26,7 +26,7 @@
     <message>
         <location filename="../default_model.cpp" line="146"/>
         <source>Shortcut</source>
-        <translation>Tastatursnarevei</translation>
+        <translation>Tastatursnarvei</translation>
     </message>
     <message>
         <location filename="../default_model.cpp" line="149"/>
@@ -54,7 +54,7 @@
     <message>
         <location filename="../edit_action_dialog.ui" line="31"/>
         <source>&amp;Shortcut:</source>
-        <translation>&amp;Tastatursnarevei:</translation>
+        <translation>&amp;Tastatursnarvei:</translation>
     </message>
     <message>
         <location filename="../edit_action_dialog.ui" line="74"/>
@@ -74,7 +74,7 @@
     <message>
         <location filename="../edit_action_dialog.ui" line="109"/>
         <source>&amp;DBus message</source>
-        <translation>&amp;DBus-beskjed</translation>
+        <translation>&amp;DBus-melding</translation>
     </message>
     <message>
         <location filename="../edit_action_dialog.ui" line="118"/>
@@ -174,7 +174,7 @@
         <translation>Standard</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Lukk</translation>
     </message>
@@ -187,8 +187,23 @@
         <location filename="../main_window.cpp" line="192"/>
         <source>Your defined shortcuts will be removed.
 Do you want to proceed?</source>
-        <translation>Dine egne tastatursnareveiertastatursnarvei blir tatt vekk.
-Ønsker du å fortsette?</translation>
+        <translation>Dine definerte tastatursnarveier fjernes.
+Vil du fortsette?</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Plattform ikke støttet</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
