@@ -174,7 +174,7 @@
         <translation>Standaard</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Sluiten</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Weet u zeker dat u wilt doorgaan?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Geen ondersteund platform</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>Globale sneltoetsen op Wayland worden momenteel niet door LXQt ondersteund.
+
+Stel deze in in de instellingen van de vensterbeheerder.</translation>
+    </message>
+</context>
 </TS>
