@@ -174,7 +174,7 @@
         <translation>Padrão</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Fechar</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Tem a certeza de que deseja continuar?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Plataforma não suportada</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>As teclas globais do LXQt não são suportadas atualmente no Wayland.
+
+Em vez disso, os atalhos globais podem ser configurados nas definições do compositor.</translation>
+    </message>
+</context>
 </TS>
