@@ -174,7 +174,7 @@
         <translation>Varsayılan</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Kapat</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Devam etmek istiyor musunuz?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Desteklenmeyen Platform</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>LXQt evrensel tuşlar şu anda Wayland altında desteklenmemektedir.
+
+Bunun yerine evrensel kısayollar kompozitörün ayarlarından yapılandırılabilir.</translation>
+    </message>
+</context>
 </TS>
