@@ -174,7 +174,7 @@
         <translation>Типова</translation>
     </message>
     <message>
-        <location filename="../main_window.ui" line="203"/>
+        <location filename="../main_window.ui" line="207"/>
         <source>Close</source>
         <translation>Закрити</translation>
     </message>
@@ -191,4 +191,21 @@ Do you want to proceed?</source>
 Хочете продовжити?</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Platform Unsupported</source>
+        <translation>Непідтримувана платформа</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="52"/>
+        <source>LXQt globalkeys are currently unsupported under Wayland.
+
+Global shortcuts can be configured in the settings of the compositor instead.</source>
+        <translation>Глобальні клавіші LXQt наразі не підтримуються у Wayland.
+
+Замість них можна налаштувати глобальні комбінації клавіш у налаштуваннях композитора.</translation>
+    </message>
+</context>
 </TS>
